##  Example 3: How to Model Business Architecture with Customer Journey and Business Products (Digital Bank)
The example company, a digital bank, focuses more on building products for its customers. The focus is not on creating an extensive repository of business processes and ways to increase efficiency but improving customer satisfaction. In this case, it makes sense to model both business products and customer journeys.
In this scenario:
  1. A distinction between business applications and business products would usually be required (although for SaaS products, this may not be the case), as the latter is more focused on the specific commercial offering to the customer. Unique attributes of the business product may include the type of pricing metric, for example.
  2. The need to analyze how the customer perceives this offering via the modeling of customer journeys. Customer satisfaction can be measured via NPS or other surveys here. There might also be a dotted line between the customer journey and the business product.


Ultimately, the focus in terms of organization here is on your customer, whichever way they have been defined; in scenarios like this one, using personas is a common approach.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275087de7a441014a343c25ab1cb7647_LowRes.png)
